@@ -513,6 +513,8 @@ BooleanFormula * parseRTree(SEXP formula, unsigned int * memorySizes,
 			op = OPERATOR_TIMEGT;
 		else if (strcmp(operator, "timelt") == 0)
 			op = OPERATOR_TIMELT;
+		else
+			error("Unknown operator!");
 
 		SEXP operands = getListElement(formula, "operands");
 		BooleanOperator * res = allocOperator(op,
@@ -883,8 +885,8 @@ SEXP symbolicSATSearch_R(SEXP network, SEXP maxAttractorSize,
 		el = el->next;
 	}
 	SETCADDR(retSXP, attractorListSXP);
-	UNPROTECT(2);
-	PutRNGstate();
+    PutRNGstate();
+    UNPROTECT(2);
 	return (retSXP);
 }
 
@@ -1377,7 +1379,7 @@ SEXP simulateStates_R(SEXP network, SEXP states, SEXP maxTransitions,
 /**
  * Check whether <ptr> is a null pointer.
  */
-SEXP checkNullPointer(SEXP ptr)
+SEXP checkNullPointerC(SEXP ptr)
 {
 	void * p = R_ExternalPtrAddr(ptr);
 
